@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 __protobuf__ = proto.module(
@@ -36,11 +38,11 @@ class ReleaseRenderEvent(proto.Message):
             The name of the ``Release``.
     """
 
-    message = proto.Field(
+    message: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    release = proto.Field(
+    release: str = proto.Field(
         proto.STRING,
         number=2,
     )
